#!/bin/sh

# setvers.sh - extract version numbers from the changelog and kernel
#	source and build the control file and prerm script for the
#	pcmcia-modules package

# KSRC is expected to be passed through the environment

set -e

# define some sed scripts for extracting the upstream version number
# and Debian revision number from a Debian changelog
up_vers_sed='
	1{
	  s/^[^(]*(//
	  s/)[^)]*$//
	  /^[0-9]\{1,\}:/{
	    s///
	    b endepoch
	  }
	  /:/q
	  :endepoch
	  /-[A-Za-z0-9.+]*$/{
	    s///
	    b enddeb
	  }
	  /-/q
	  :enddeb
	  /^[A-Za-z0-9.+:-]\{1,\}$/p
	  q
	}'
deb_rev_sed='
	1{
	  s/^[^(]*(//
	  s/)[^)]*$//
	  s/^.*-\([A-Za-z0-9.+]*\)$/\1/p
	  q
	}'
KVERS=`sed -n '/UTS_RELEASE=/{
                 s///
                 p
                 q
               }' config.mk`

# extract the upstream version number and debian revision number
UPVERS=`sed -n "$up_vers_sed" debian/changelog`
DEBREV=`sed -n "$deb_rev_sed" debian/changelog`

# determine the version numbers for the kernel source
# use a Debian changelog if it exists, otherwise use the kernel version
# number determined by the PCMCIA configure script
if test -r "$KSRC/debian/changelog"
then
	KDEBREV=`sed -n "$deb_rev_sed" "$KSRC/debian/changelog"`
	KVERSDEB=`sed -n "$up_vers_sed" "$KSRC/debian/changelog"`
else
	KDEBREV=""
	KVERSDEB="$KVERS"
fi

# test whether we have successfully determined the version numbers
test "$KVERS" -a "$UPVERS" -a "$DEBREV" || exit 1

echo "$KVERS" > debian/KVERS
if [ "$KVERS" = "$KVERSDEB" ]
then
	MODVERS="$UPVERS-${DEBREV}${KDEBREV:+k$KDEBREV}"
else
	MODVERS="$UPVERS-${DEBREV}+"`echo "$KVERSDEB" | tr - +`${KDEBREV:+"+$KDEBREV"}
fi
echo "$MODVERS" > debian/MODVERS

# Generate a correct control file and prerm script for the modules package
for script in preinst postinst prerm
do
    sed 's/\${kvers}/'$KVERS'/g
	 s/\${kversdeb}/'$KVERSDEB'/g' \
    	debian/$script-modules.in > debian/tmp-modules/DEBIAN/$script
    chmod +x debian/tmp-modules/DEBIAN/$script
done

cat debian/control-source > debian/control.tmp
if [ "$KVERS" = "$KVERSDEB" ]
then
    sed 's/\${kvers}/'$KVERS'/g' debian/control-modules >> debian/control.tmp
else
    sed 's/\${kvers}/'$KVERS'/g' debian/control-modules | \
    	grep -v 'Recommends:' >> debian/control.tmp
fi

dpkg-gencontrol	-Vkversdeb="$KVERSDEB${KDEBREV:+-$KDEBREV}" -v"$MODVERS" \
	-p"pcmcia-modules-$KVERS" -Pdebian/tmp-modules	\
	-cdebian/control.tmp -fdebian/files-modules
exit 0
